pub type FakeCreateAction = CreateAction<FakeFileSystem>;Expand description
A Fake create action that works on a fake test filesystem.
Aliased Type
pub struct FakeCreateAction { /* private fields */ }pub type FakeCreateAction = CreateAction<FakeFileSystem>;A Fake create action that works on a fake test filesystem.
pub struct FakeCreateAction { /* private fields */ }