pub type NativeCreateAction = CreateAction<OsFileSystem>;Expand description
A native create action that works on the real filesystem.
Aliased Type
pub struct NativeCreateAction { /* private fields */ }pub type NativeCreateAction = CreateAction<OsFileSystem>;A native create action that works on the real filesystem.
pub struct NativeCreateAction { /* private fields */ }